#!/bin/bash

###########################################################################
#
# MODULE:       GUI
# AUTHOR(S):    CacheGuard Development Team
# COPYRIGHT:    (C) 2009-2021 by CacheGuard Technologies Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
###########################################################################

show-tls-objects()
{
    local in_tls=${1}

    local selected tls

    for tls in ${TLS_LIST}
    do
	if test "${in_tls}" == ${tls} ; then
	    selected=' selected'
	else
	    unset selected
	fi

	echo "<option value='${tls}' id='${tls}'${selected}>${tls}</option>"
    done
}

show-tls-ca-objects()
{
    local in_ca=${1}

    local i=0 elt range
    local ca selected

    echo "<option value='' id='nil'></option>"

    for elt in system on ${CA_LIST}
    do
	range=$[${i} % 2]
	case ${range} in
	    0)
		ca=${elt}
		;;
	    1)
		if test "${in_ca}" == ${ca} ; then
		    selected=' selected'
		else
		    unset selected
		fi

		echo "<option value='${ca}' id='${ca}'${selected}>${ca}</option>"
		;;
	    *)
		return 1
		;;
	esac
	((i++))
    done
}

show-ocsp-days()
{
    local days=${1}

    local i max=31

    for ((i=1 ; i<=max ; i++))
    do
	if test ${i} -eq ${days} ; then
	    selected=' selected'
	else
	    unset selected
	fi
	echo -n "<option value='${i}' id='${i}'${selected}>${i}</option>"
    done
}

show-ocsp-tls()
{
    local in_tls=${1}

    local tls selected

    echo "<option value='' id='nil'></option>"

    for tls in ${TLS_LIST}
    do
	if test "${in_tls}" == "${tls}" ; then
	    selected=' selected'
	else
	    unset selected
	fi
	echo "<option value='${tls}' id='${tls}'${selected}>${tls}</option>"
    done
}

show-tls-ocsp-etc()
{
    local width=400 i=0

    itemWidth[0]=50
    itemWidth[1]=50

    itemTitle[${i}]="Web Administration & SNMP TLS Object" ; ((i++))
    itemTitle[${i}]="PKI Server Certificates Validity Days" ; ((i++))
    itemTitle[${i}]="PKI Client Certificates Validity Days" ; ((i++))
    itemTitle[${i}]="OCSP Responder Network Name" ; ((i++))
    itemTitle[${i}]="OCSP Responder Port Number" ; ((i++))
    itemTitle[${i}]="OCSP Responses Validity Days" ; ((i++))
    itemTitle[${i}]="TLS to Sign/Check OCSP Responses" ; ((i++))
    itemTitle[${i}]="LDAPS Verification CA Certificate" ; ((i++))

    i=0
    itemID[${i}]="admin_tls" ; ((i++))
    itemID[${i}]="tls_days" ; ((i++))
    itemID[${i}]="tls_client_days" ; ((i++))
    itemID[${i}]="tls_ocsp_host" ; ((i++))
    itemID[${i}]="port_ocsp" ; ((i++))
    itemID[${i}]="tls_ocsp_days" ; ((i++))
    itemID[${i}]="tls_ocsp_tls" ; ((i++))
    itemID[${i}]="ldaps_ca" ; ((i++))

    i=0
    itemForm[${i}]="select" ; ((i++))
    itemForm[${i}]="input" ; ((i++))
    itemForm[${i}]="input" ; ((i++))
    itemForm[${i}]="input" ; ((i++))
    itemForm[${i}]="input" ; ((i++))
    itemForm[${i}]="select" ; ((i++))
    itemForm[${i}]="select" ; ((i++))
    itemForm[${i}]="select" ; ((i++))

    i=0
    blankItemContent[${i}]=$(show-tls-objects ${ADMIN_TLS}) ; ((i++))
    blankItemContent[${i}]="type='text' size='8' maxlength='8' value='${TLS_SERVER_DAYS}'" ; ((i++))
    blankItemContent[${i}]="type='text' size='8' maxlength='8' value='${TLS_CLIENT_DAYS}'" ; ((i++))
    blankItemContent[${i}]="type='text' size='32' maxlength='64' value='${OCSP_HOST}'" ; ((i++))
    blankItemContent[${i}]="type=text size=5 maxlength=5 value='${OCSP_PORT}'" ; ((i++))
    blankItemContent[${i}]=$(show-ocsp-days ${OCSP_DAYS}) ; ((i++))
    blankItemContent[${i}]=$(show-ocsp-tls ${OCSP_TLS}) ; ((i++))
    blankItemContent[${i}]=$(show-tls-ca-objects ${LDAPS_CA}) ; ((i++))

    i=0
    checkItem[${i}]=tls ; ((i++))
    checkItem[${i}]=digit ; ((i++))
    checkItem[${i}]=digit ; ((i++))
    checkItem[${i}]=domainname ; ((i++))
    checkItem[${i}]=digit ; ((i++))
    checkItem[${i}]=digit ; ((i++))
    checkItem[${i}]=tls ; ((i++))
    checkItem[${i}]=tls ; ((i++))

    shortcutMenuItem[0]="tls"
    shortcutMenuTitle[0]="Manage Server TLS"

    shortcutMenuItem[1]="tls-ca"
    shortcutMenuTitle[1]="Manage CA Certificates"

    shortcutMenuItem[2]="port"
    shortcutMenuTitle[2]="Listening Ports"

    show-title "OCSP and Other TLS Settings" "enabled" "admin authenticate port tls"
    show-shortcuts-menu
    show-form "${width}"
}

# Main()

show-tls-ocsp-etc
